@@ -75,7 +75,12 @@ class DCCAE(_DCCA_base):
         z = self(*args)
         recon = self._decode(*z)
         recon_loss = self._recon_loss(args[: len(recon)], recon)
-        return self.lam * recon_loss + self.objective.loss(*z)
+        return {
+            "objective": self.lam * recon_loss
+            + (1 - self.lam) * self.objective.loss(*z),
+            "reconstruction": recon_loss,
+            "correlation loss": self.objective.loss(*z),
+        }
 
     @staticmethod
     def _recon_loss(x, recon):
