@@ -48,18 +48,18 @@ class CCALightning(LightningModule):
 
     def training_step(self, batch, batch_idx):
         loss = self.model.loss(*batch["views"])
-        self.log("train loss", loss)
-        return loss
+        self.log("train", loss, prog_bar=True)
+        return loss["objective"]
 
     def validation_step(self, batch, batch_idx):
         loss = self.model.loss(*batch["views"])
-        self.log("val loss", loss)
-        return loss
+        self.log("val", loss)
+        return loss["objective"]
 
     def test_step(self, batch, batch_idx):
         loss = self.model.loss(*batch["views"])
-        self.log("test loss", loss)
-        return loss
+        self.log("test", loss)
+        return loss["objective"]
 
     def on_train_epoch_end(self, unused: Optional = None) -> None:
         score = self.score(self.trainer.train_dataloader, train=True).sum()
@@ -110,6 +110,8 @@ class CCALightning(LightningModule):
             for batch_idx, batch in enumerate(loader):
                 views = [view.to(self.device) for view in batch["views"]]
                 z = self.model(*views)
+                if isinstance(z[0], dict):
+                    z = z[0]["shared"]
                 if batch_idx == 0:
                     z_list = [z_i.detach().cpu().numpy() for i, z_i in enumerate(z)]
                 else:
