@@ -51,7 +51,7 @@ train_loader, val_loader = get_dataloaders(train_dataset, val_dataset, batch_siz
 # The number of latent dimensions across models
 latent_dims = 2
 # number of epochs for deep models
-epochs = 20
+epochs = 50
 
 encoder_1 = architectures.Encoder(latent_dims=latent_dims, feature_size=392)
 encoder_2 = architectures.Encoder(latent_dims=latent_dims, feature_size=392)
@@ -60,7 +60,12 @@ encoder_2 = architectures.Encoder(latent_dims=latent_dims, feature_size=392)
 # Deep CCA
 dcca = DCCA(latent_dims=latent_dims, encoders=[encoder_1, encoder_2])
 dcca = CCALightning(dcca)
-trainer = pl.Trainer(max_epochs=epochs, enable_checkpointing=False)
+trainer = pl.Trainer(
+    max_epochs=epochs,
+    enable_checkpointing=False,
+    log_every_n_steps=1,
+    flush_logs_every_n_steps=1,
+)
 trainer.fit(dcca, train_loader, val_loader)
 plot_latent_label(dcca.model, train_loader)
 plt.suptitle("DCCA")
@@ -72,7 +77,12 @@ dcca_noi = DCCA_NOI(
     latent_dims=latent_dims, N=len(train_dataset), encoders=[encoder_1, encoder_2]
 )
 dcca_noi = CCALightning(dcca_noi)
-trainer = pl.Trainer(max_epochs=epochs, enable_checkpointing=False)
+trainer = pl.Trainer(
+    max_epochs=epochs,
+    enable_checkpointing=False,
+    log_every_n_steps=1,
+    flush_logs_every_n_steps=1,
+)
 trainer.fit(dcca_noi, train_loader, val_loader)
 plot_latent_label(dcca_noi.model, train_loader)
 plt.suptitle("DCCA by Non-Linear Orthogonal Iterations")
@@ -84,7 +94,12 @@ dcca_sdl = DCCA_SDL(
     latent_dims=latent_dims, N=len(train_dataset), encoders=[encoder_1, encoder_2]
 )
 dcca_sdl = CCALightning(dcca_sdl)
-trainer = pl.Trainer(max_epochs=epochs, enable_checkpointing=False)
+trainer = pl.Trainer(
+    max_epochs=epochs,
+    enable_checkpointing=False,
+    log_every_n_steps=1,
+    flush_logs_every_n_steps=1,
+)
 trainer.fit(dcca_sdl, train_loader, val_loader)
 plot_latent_label(dcca_sdl.model, train_loader)
 plt.suptitle("DCCA by Stochastic Decorrelation")
@@ -94,8 +109,13 @@ plt.show()
 # Deep CCA by Barlow Twins
 barlowtwins = BarlowTwins(latent_dims=latent_dims, encoders=[encoder_1, encoder_2])
 barlowtwins = CCALightning(barlowtwins)
-trainer = pl.Trainer(max_epochs=epochs, enable_checkpointing=False)
-trainer.fit(dcca, train_loader, val_loader)
-plot_latent_label(dcca_sdl.model, train_loader)
+trainer = pl.Trainer(
+    max_epochs=epochs,
+    enable_checkpointing=False,
+    log_every_n_steps=1,
+    flush_logs_every_n_steps=1,
+)
+trainer.fit(barlowtwins, train_loader, val_loader)
+plot_latent_label(barlowtwins.model, train_loader)
 plt.suptitle("DCCA by Barlow Twins")
 plt.show()
